@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU General Public License
 # along with Plowshare.  If not, see <http://www.gnu.org/licenses/>.
 
-declare -r VERSION='v2.1.2 (2015-09-13)'
+declare -r VERSION='v2.1.3 (2016-03-24)'
 
 # Default repository source
 declare -r LEGACY_MODULES='https://github.com/mcrapet/plowshare-modules-legacy.git'
@@ -69,7 +69,7 @@ EOH
     print_options "$ACTION_OPTIONS"
     cat <<EOH
 
-For install, if no source repositoy is specified use:
+For install, if no source repository is specified use:
 $LEGACY_MODULES
 
 Available options:
@@ -255,7 +255,7 @@ if [ -n "$QUIET" ]; then
     if [ -z "$VERBOSE" ]; then
         declare -r VERBOSE=0
     else
-        log_notice "WARNING: --quiet switch conflits with --verbose=$VERBOSE, ignoring -q"
+        log_notice "WARNING: --quiet switch conflicts with --verbose=$VERBOSE, ignoring -q"
     fi
 elif [ -z "$VERBOSE" ]; then
     declare -r VERBOSE=2
